// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
// SPDX-License-Identifier: BSD-3-Clause

// Object factories should never have deprecation warnings.
// NOLINTNEXTLINE(modernize-macro-to-enum)
#define VTK_DEPRECATION_LEVEL 0

#include "vtkFiltersParallelFlowPathsObjectFactory.h"
#include "vtkVersion.h"

// Include all of the classes we want to create overrides for.
#include "vtkPLagrangianParticleTracker.h"
#include "vtkPStreamTracer.h"
#include "vtkPParticleTracer.h"
#include "vtkPParticlePathFilter.h"
#include "vtkPStreaklineFilter.h"


VTK_ABI_NAMESPACE_BEGIN

vtkStandardNewMacro(vtkFiltersParallelFlowPathsObjectFactory);

// Now create the functions to create overrides with.
VTK_CREATE_CREATE_FUNCTION(vtkPLagrangianParticleTracker)
VTK_CREATE_CREATE_FUNCTION(vtkPStreamTracer)
VTK_CREATE_CREATE_FUNCTION(vtkPParticleTracer)
VTK_CREATE_CREATE_FUNCTION(vtkPParticlePathFilter)
VTK_CREATE_CREATE_FUNCTION(vtkPStreaklineFilter)


vtkFiltersParallelFlowPathsObjectFactory::vtkFiltersParallelFlowPathsObjectFactory()
{
this->RegisterOverride("vtkLagrangianParticleTracker", "vtkPLagrangianParticleTracker", "Override for VTK::FiltersParallelFlowPaths module", 1, vtkObjectFactoryCreatevtkPLagrangianParticleTracker);
this->RegisterOverride("vtkStreamTracer", "vtkPStreamTracer", "Override for VTK::FiltersParallelFlowPaths module", 1, vtkObjectFactoryCreatevtkPStreamTracer);
this->RegisterOverride("vtkParticleTracer", "vtkPParticleTracer", "Override for VTK::FiltersParallelFlowPaths module", 1, vtkObjectFactoryCreatevtkPParticleTracer);
this->RegisterOverride("vtkParticlePathFilter", "vtkPParticlePathFilter", "Override for VTK::FiltersParallelFlowPaths module", 1, vtkObjectFactoryCreatevtkPParticlePathFilter);
this->RegisterOverride("vtkStreaklineFilter", "vtkPStreaklineFilter", "Override for VTK::FiltersParallelFlowPaths module", 1, vtkObjectFactoryCreatevtkPStreaklineFilter);

}

const char * vtkFiltersParallelFlowPathsObjectFactory::GetVTKSourceVersion()
{
  return VTK_SOURCE_VERSION;
}

void vtkFiltersParallelFlowPathsObjectFactory::PrintSelf(ostream &os, vtkIndent indent)
{
  this->Superclass::PrintSelf(os, indent);
}

// Registration of object factories.
static unsigned int vtkFiltersParallelFlowPathsCount = 0;

VTKFILTERSPARALLELFLOWPATHS_EXPORT void vtkFiltersParallelFlowPaths_AutoInit_Construct()
{
  if(++vtkFiltersParallelFlowPathsCount == 1)
  {


    vtkFiltersParallelFlowPathsObjectFactory* factory = vtkFiltersParallelFlowPathsObjectFactory::New();
    if (factory)
    {
      // vtkObjectFactory keeps a reference to the "factory",
      vtkObjectFactory::RegisterFactory(factory);
      factory->Delete();
    }
  }
}
VTK_ABI_NAMESPACE_END
